@@ -5,17 +5,14 @@ from rest_framework.response import Response
 from rest_framework.views import APIView
 
 logger = logging.getLogger('console.log')
-loggers = {
-    'info': logger.info,
-    'error': logger.error
-}
+loggers = {'info': logger.info, 'error': logger.error}
 
 
 class JsLoggerApi(APIView):
     @staticmethod
     def post(request: Request) -> Response:
         """
-        Logs received logs from the client.
+        Receives logs from the client, which we re-log with a python logger.
         """
         if 'msg' in request.data and 'type' in request.data:
             loggers[request.data['type']](request.data['msg'])
